@@ -10,6 +10,10 @@ bad = random.choice()
 bad = random.choices()
 bad = random.uniform()
 bad = random.triangular()
+bad = random.randbytes()
+bad = random.sample()
+bad = random.randrange()
+bad = random.getrandbits()
 
 good = os.urandom()
 good = random.SystemRandom()
